@@ -11,6 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from ..parallelism_config import ParallelismConfig
 from .ao import convert_model_to_fp8_ao, filter_first_and_last_linear_layers, has_ao_layers
 from .constants import (
     MITA_PROFILING_AVAILABLE_PYTORCH_VERSION,
@@ -41,6 +42,7 @@ from .dataclasses import (
     DataLoaderConfiguration,
     DDPCommunicationHookType,
     DeepSpeedPlugin,
+    DeepSpeedSequenceParallelConfig,
     DistributedDataParallelKwargs,
     DistributedType,
     DynamoBackend,
@@ -60,7 +62,9 @@ from .dataclasses import (
     SageMakerDistributedType,
     TensorInformation,
     TERecipeKwargs,
+    TorchContextParallelConfig,
     TorchDynamoPlugin,
+    TorchTensorParallelConfig,
     TorchTensorParallelPlugin,
     add_model_config_to_megatron_parser,
 )
@@ -71,6 +75,7 @@ from .environment import (
     clear_environment,
     convert_dict_to_env_variables,
     get_cpu_distributed_information,
+    get_current_device_type,
     get_gpu_info,
     get_int_from_env,
     parse_choice_from_env,
@@ -131,6 +136,7 @@ from .imports import (
     is_torchvision_available,
     is_trackio_available,
     is_transformer_engine_available,
+    is_transformer_engine_mxfp8_available,
     is_transformers_available,
     is_triton_available,
     is_wandb_available,
