@@ -114,6 +114,14 @@ def is_transformer_engine_available():
         return _is_package_available("transformer_engine", "transformer-engine")
 
 
+def is_transformer_engine_mxfp8_available():
+    if _is_package_available("transformer_engine", "transformer-engine"):
+        import transformer_engine.pytorch as te
+
+        return te.fp8.check_mxfp8_support()[0]
+    return False
+
+
 def is_lomo_available():
     return _is_package_available("lomo_optim")
 
@@ -174,7 +182,7 @@ def is_bf16_available(ignore_tpu=False):
     if is_xpu_available():
         return torch.xpu.is_bf16_supported()
     if is_mps_available():
-        return False
+        return torch.backends.mps.is_macos_or_newer(14, 0)
     return True
 
 
@@ -406,7 +414,12 @@ def is_npu_available(check_device=False):
     if importlib.util.find_spec("torch_npu") is None:
         return False
 
-    import torch_npu  # noqa: F401
+    # NOTE: importing torch_npu may raise error in some envs
+    # e.g. inside cpu-only container with torch_npu installed
+    try:
+        import torch_npu  # noqa: F401
+    except Exception:
+        return False
 
     if check_device:
         try:
