@@ -32,6 +32,7 @@ from .imports import (
     is_torch_distributed_available,
     is_torch_xla_available,
 )
+from .versions import is_torch_version
 
 
 if is_torch_xla_available():
@@ -316,8 +317,8 @@ def _gpu_gather(tensor):
     state = PartialState()
     gather_op = torch.distributed.all_gather_into_tensor
 
-    # FIXME: the below 2 lines are added to work-aound a bug related to INT64 collectives in oneCCL. Remove them once pytorch-2.9 is released.
-    if state.device.type == "xpu":
+    # NOTE: need manually synchronize to workaourd a INT64 collectives bug in oneCCL before torch 2.9.0
+    if state.device.type == "xpu" and is_torch_version("<=", "2.8"):
         torch.xpu.synchronize()
 
     def _gpu_gather_one(tensor):
@@ -519,7 +520,7 @@ def gather_tensor_shape(tensor):
 
 def copy_tensor_to_devices(tensor=None) -> torch.Tensor:
     """
-    Copys a tensor that only exists on a single device and broadcasts it to other devices. Differs from `broadcast` as
+    Copies a tensor that only exists on a single device and broadcasts it to other devices. Differs from `broadcast` as
     each worker doesn't need to know its shape when used (and tensor can be `None`)
 
     Args:
@@ -558,7 +559,7 @@ def broadcast(tensor, from_process: int = 0):
 
 def broadcast_object_list(object_list, from_process: int = 0):
     """
-    Broadcast a list of picklable objects form one process to the others.
+    Broadcast a list of picklable objects from one process to the others.
 
     Args:
         object_list (list of picklable objects):
@@ -731,7 +732,7 @@ def reduce(tensor, reduction="mean", scale=1.0):
         reduction (`str`, *optional*, defaults to `"mean"`):
             A reduction method. Can be of "mean", "sum", or "none"
         scale (`float`, *optional*):
-            A default scaling value to be applied after the reduce, only valied on XLA.
+            A default scaling value to be applied after the reduce, only valid on XLA.
 
     Returns:
         The same data structure as `data` with all the tensors reduced.
@@ -787,7 +788,7 @@ def convert_to_fp32(tensor):
 
 class ConvertOutputsToFp32:
     """
-    Decorator to apply to a function outputing tensors (like a model forward pass) that ensures the outputs in FP16
+    Decorator to apply to a function outputting tensors (like a model forward pass) that ensures the outputs in FP16
     precision will be convert back to FP32.
 
     Args:
