@@ -18,7 +18,6 @@ import os
 import random
 import shutil
 import tempfile
-import unittest
 import uuid
 from contextlib import contextmanager
 
@@ -29,8 +28,15 @@ from torch import nn
 from torch.utils.data import DataLoader, TensorDataset
 
 from accelerate import Accelerator
-from accelerate.test_utils import device_count, execute_subprocess_async, require_non_cpu
-from accelerate.utils import ProjectConfiguration, set_seed
+from accelerate.test_utils import (
+    DEFAULT_LAUNCH_COMMAND,
+    execute_subprocess_async,
+    require_non_cpu,
+    require_non_torch_xla,
+    run_first,
+)
+from accelerate.test_utils.testing import AccelerateTestCase
+from accelerate.utils import DistributedType, ProjectConfiguration, patch_environment, set_seed
 
 
 logger = logging.getLogger(__name__)
@@ -89,7 +95,16 @@ def parameterized_custom_name_func(func, param_num, param):
 
 
 @parameterized_class(("use_safetensors",), [[True], [False]], class_name_func=parameterized_custom_name_func)
-class CheckpointTest(unittest.TestCase):
+class CheckpointTest(AccelerateTestCase):
+    def check_adam_state(self, state1, state2, distributed_type):
+        # For DistributedType.XLA, the `accelerator.save_state` function calls `xm._maybe_convert_to_cpu` before saving.
+        # As a result, all tuple values are converted to lists. Therefore, we need to convert them back here.
+        # Remove this code once Torch XLA fixes this issue.
+        if distributed_type == DistributedType.XLA:
+            state1["param_groups"][0]["betas"] = tuple(state1["param_groups"][0]["betas"])
+            state2["param_groups"][0]["betas"] = tuple(state2["param_groups"][0]["betas"])
+        assert state1 == state2
+
     def test_with_save_limit(self):
         with tempfile.TemporaryDirectory() as tmpdir:
             set_seed(42)
@@ -107,7 +122,7 @@ class CheckpointTest(unittest.TestCase):
 
             # Save second state
             accelerator.save_state(safe_serialization=self.use_safetensors)
-            self.assertEqual(len(os.listdir(accelerator.project_dir)), 1)
+            assert len(os.listdir(accelerator.project_dir)) == 1
 
     def test_can_resume_training_with_folder(self):
         with tempfile.TemporaryDirectory() as tmpdir:
@@ -143,7 +158,9 @@ class CheckpointTest(unittest.TestCase):
             opt_state2 = optimizer.state_dict()
             self.assertEqual(a, a2)
             self.assertEqual(b, b2)
-            self.assertEqual(opt_state, opt_state2)
+            assert a == a2
+            assert b == b2
+            self.check_adam_state(opt_state, opt_state2, accelerator.distributed_type)
 
             test_rands = train(2, model, train_dataloader, optimizer, accelerator)
             # Save everything
@@ -155,10 +172,10 @@ class CheckpointTest(unittest.TestCase):
             test_rands += train(1, model, train_dataloader, optimizer, accelerator)
             (a3, b3) = model.a.item(), model.b.item()
             opt_state3 = optimizer.state_dict()
-            self.assertEqual(a1, a3)
-            self.assertEqual(b1, b3)
-            self.assertEqual(opt_state1, opt_state3)
-            self.assertEqual(ground_truth_rands, test_rands)
+            assert a1 == a3
+            assert b1 == b3
+            self.check_adam_state(opt_state1, opt_state3, accelerator.distributed_type)
+            assert ground_truth_rands == test_rands
 
     def test_can_resume_training(self):
         with tempfile.TemporaryDirectory() as tmpdir:
@@ -194,9 +211,9 @@ class CheckpointTest(unittest.TestCase):
             accelerator.load_state(os.path.join(tmpdir, "checkpoints", "checkpoint_0"))
             (a2, b2) = model.a.item(), model.b.item()
             opt_state2 = optimizer.state_dict()
-            self.assertEqual(a, a2)
-            self.assertEqual(b, b2)
-            self.assertEqual(opt_state, opt_state2)
+            assert a == a2
+            assert b == b2
+            self.check_adam_state(opt_state, opt_state2, accelerator.distributed_type)
 
             test_rands = train(2, model, train_dataloader, optimizer, accelerator)
             # Save everything
@@ -207,10 +224,10 @@ class CheckpointTest(unittest.TestCase):
             test_rands += train(1, model, train_dataloader, optimizer, accelerator)
             (a3, b3) = model.a.item(), model.b.item()
             opt_state3 = optimizer.state_dict()
-            self.assertEqual(a1, a3)
-            self.assertEqual(b1, b3)
-            self.assertEqual(opt_state1, opt_state3)
-            self.assertEqual(ground_truth_rands, test_rands)
+            assert a1 == a3
+            assert b1 == b3
+            self.check_adam_state(opt_state1, opt_state3, accelerator.distributed_type)
+            assert ground_truth_rands == test_rands
 
     def test_can_resume_training_checkpoints_relative_path(self):
         # See #1983
@@ -259,9 +276,10 @@ class CheckpointTest(unittest.TestCase):
             accelerator.load_state()  # <= infer the directory automatically
             (a2, b2) = model.a.item(), model.b.item()
             opt_state2 = optimizer.state_dict()
-            self.assertEqual(a, a2)
-            self.assertEqual(b, b2)
-            self.assertEqual(opt_state, opt_state2)
+            assert a == a2
+            assert b == b2
+            self.check_adam_state(opt_state, opt_state2, accelerator.distributed_type)
+            assert opt_state == opt_state2
 
             test_rands = train(2, model, train_dataloader, optimizer, accelerator)
             # Save everything
@@ -272,10 +290,10 @@ class CheckpointTest(unittest.TestCase):
             test_rands += train(1, model, train_dataloader, optimizer, accelerator)
             (a3, b3) = model.a.item(), model.b.item()
             opt_state3 = optimizer.state_dict()
-            self.assertEqual(a1, a3)
-            self.assertEqual(b1, b3)
-            self.assertEqual(opt_state1, opt_state3)
-            self.assertEqual(ground_truth_rands, test_rands)
+            assert a1 == a3
+            assert b1 == b3
+            self.check_adam_state(opt_state1, opt_state3, accelerator.distributed_type)
+            assert ground_truth_rands == test_rands
 
     def test_invalid_registration(self):
         t = torch.tensor([1, 2, 3])
@@ -286,10 +304,10 @@ class CheckpointTest(unittest.TestCase):
         with self.assertRaises(ValueError) as ve:
             accelerator.register_for_checkpointing(t, t1, net, opt)
         message = str(ve.exception)
-        self.assertTrue("Item at index 0" in message)
-        self.assertTrue("Item at index 1" in message)
-        self.assertFalse("Item at index 2" in message)
-        self.assertFalse("Item at index 3" in message)
+        assert "Item at index 0" in message
+        assert "Item at index 1" in message
+        assert "Item at index 2" not in message
+        assert "Item at index 3" not in message
 
     def test_with_scheduler(self):
         with tempfile.TemporaryDirectory() as tmpdir:
@@ -308,11 +326,11 @@ class CheckpointTest(unittest.TestCase):
             accelerator.save_state(safe_serialization=self.use_safetensors)
             scheduler_state = scheduler.state_dict()
             train(3, model, train_dataloader, optimizer, accelerator, scheduler)
-            self.assertNotEqual(scheduler_state, scheduler.state_dict())
+            assert scheduler_state != scheduler.state_dict()
 
             # Load everything back in and make sure all states work
             accelerator.load_state(os.path.join(tmpdir, "checkpoints", "checkpoint_0"))
-            self.assertEqual(scheduler_state, scheduler.state_dict())
+            assert scheduler_state == scheduler.state_dict()
 
     def test_automatic_loading(self):
         with tempfile.TemporaryDirectory() as tmpdir:
@@ -338,10 +356,10 @@ class CheckpointTest(unittest.TestCase):
 
             # Load back in the last saved checkpoint, should point to a2, b2
             accelerator.load_state()
-            self.assertNotEqual(a3, model.a.item())
-            self.assertNotEqual(b3, model.b.item())
-            self.assertEqual(a2, model.a.item())
-            self.assertEqual(b2, model.b.item())
+            assert a3 != model.a.item()
+            assert b3 != model.b.item()
+            assert a2 == model.a.item()
+            assert b2 == model.b.item()
 
     def test_checkpoint_deletion(self):
         with tempfile.TemporaryDirectory() as tmpdir:
@@ -354,17 +372,19 @@ class CheckpointTest(unittest.TestCase):
             # Save 3 states:
             for _ in range(11):
                 accelerator.save_state(safe_serialization=self.use_safetensors)
-            self.assertTrue(not os.path.exists(os.path.join(tmpdir, "checkpoints", "checkpoint_0")))
-            self.assertTrue(os.path.exists(os.path.join(tmpdir, "checkpoints", "checkpoint_9")))
-            self.assertTrue(os.path.exists(os.path.join(tmpdir, "checkpoints", "checkpoint_10")))
+            assert not os.path.exists(os.path.join(tmpdir, "checkpoints", "checkpoint_0"))
+            assert os.path.exists(os.path.join(tmpdir, "checkpoints", "checkpoint_9"))
+            assert os.path.exists(os.path.join(tmpdir, "checkpoints", "checkpoint_10"))
 
+    @run_first
     @require_non_cpu
+    @require_non_torch_xla
     def test_map_location(self):
-        cmd = ["torchrun", f"--nproc_per_node={device_count}", inspect.getfile(self.__class__)]
-        env = os.environ.copy()
-        env["USE_SAFETENSORS"] = str(self.use_safetensors)
-        env["OMP_NUM_THREADS"] = "1"
-        execute_subprocess_async(cmd, env=env)
+        cmd = DEFAULT_LAUNCH_COMMAND + [inspect.getfile(self.__class__)]
+
+        env_kwargs = dict(use_safe_tensors=str(self.use_safetensors), omp_num_threads="1")
+        with patch_environment(**env_kwargs):
+            execute_subprocess_async(cmd)
 
 
 if __name__ == "__main__":
@@ -386,7 +406,7 @@ if __name__ == "__main__":
     )
     model, optimizer = accelerator.prepare(model, optimizer)
     train(3, model, train_dataloader, optimizer, accelerator, scheduler)
-    # Check that the intial optimizer is loaded on the GPU
+    # Check that the initial optimizer is loaded on the GPU
     for group in optimizer.param_groups:
         param_device = group["params"][0].device
         break
@@ -401,9 +421,9 @@ if __name__ == "__main__":
     for group in optimizer.param_groups:
         param_device = group["params"][0].device
         break
-    assert (
-        param_device.type == torch.device("cpu").type
-    ), f"Loaded optimizer states did not match, expected to be loaded on the CPU but got {param_device}"
+    assert param_device.type == torch.device("cpu").type, (
+        f"Loaded optimizer states did not match, expected to be loaded on the CPU but got {param_device}"
+    )
 
     # Check device state
     model.to(accelerator.device)
@@ -411,9 +431,9 @@ if __name__ == "__main__":
     for group in optimizer.param_groups:
         param_device = group["params"][0].device
         break
-    assert (
-        param_device.type == accelerator.device.type
-    ), f"Loaded optimizer states did not match, expected to be loaded on {accelerator.device} but got {param_device}"
+    assert param_device.type == accelerator.device.type, (
+        f"Loaded optimizer states did not match, expected to be loaded on {accelerator.device} but got {param_device}"
+    )
 
     # Check error
     with pytest.raises(TypeError, match="Unsupported optimizer map location passed"):
