@@ -12,20 +12,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import inspect
 import os
 import sys
 import unittest
 
-import accelerate
-from accelerate.test_utils import execute_subprocess_async, require_tpu
+from accelerate.test_utils import execute_subprocess_async, path_in_accelerate_package, require_tpu
 
 
 class MultiTPUTester(unittest.TestCase):
-    def setUp(self):
-        mod_file = inspect.getfile(accelerate.test_utils)
-        self.test_file_path = os.path.sep.join(mod_file.split(os.path.sep)[:-1] + ["scripts", "test_script.py"])
-        self.test_dir = os.path.sep.join(inspect.getfile(self.__class__).split(os.path.sep)[:-1])
+    test_file_path = path_in_accelerate_package("test_utils", "scripts", "test_script.py")
+    test_dir = os.path.dirname(__file__)
 
     @require_tpu
     def test_tpu(self):
@@ -35,4 +31,4 @@ class MultiTPUTester(unittest.TestCase):
             {self.test_file_path}
         """.split()
         cmd = [sys.executable] + distributed_args
-        execute_subprocess_async(cmd, env=os.environ.copy())
+        execute_subprocess_async(cmd)
